Index: webkit/plugins/ppapi/plugin_module.h |
diff --git a/webkit/plugins/ppapi/plugin_module.h b/webkit/plugins/ppapi/plugin_module.h |
index bf417d6882eb556c582b242431e1ed96b4a141bc..b02c70b2f42df62e1aec82682c6ba26219668944 100644 |
--- a/webkit/plugins/ppapi/plugin_module.h |
+++ b/webkit/plugins/ppapi/plugin_module.h |
@@ -83,6 +83,7 @@ class WEBKIT_PLUGINS_EXPORT PluginModule : |
// all plugin modules. In practice it will be a global singleton that |
// tracks which modules are alive. |
PluginModule(const std::string& name, |
+ const std::string& version, |
const FilePath& path, |
PluginDelegate::ModuleLifetime* lifetime_delegate, |
const ::ppapi::PpapiPermissions& perms); |
@@ -140,6 +141,7 @@ class WEBKIT_PLUGINS_EXPORT PluginModule : |
PP_Module pp_module() const { return pp_module_; } |
const std::string& name() const { return name_; } |
+ const std::string& version() const { return version_; } |
const FilePath& path() const { return path_; } |
const ::ppapi::PpapiPermissions& permissions() const { return permissions_; } |
@@ -235,8 +237,9 @@ class WEBKIT_PLUGINS_EXPORT PluginModule : |
// presence of the out_of_process_proxy_ value. |
EntryPoints entry_points_; |
// The name and file location of the module. |
const std::string name_; |
+ const std::string version_; |
const FilePath path_; |
::ppapi::PpapiPermissions permissions_; |
@@ -235,8 +237,9 @@ class WEBKIT_PLUGINS_EXPORT PluginModule : |
// presence of the out_of_process_proxy_ value. |
EntryPoints entry_points_; |
- // The name and file location of the module. |
+ // The name, version, and file location of the module. |
const std::string name_; |